@@ -2,6 +2,7 @@
 build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
+ 'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
  'ARFLAGS': 'rcs',
@@ -9,68 +10,65 @@ build_time_vars = {'ABIFLAGS': '',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/pkg/bin',
- 'BINLIBDEST': '/usr/pkg/lib/python3.7',
- 'BLDLIBRARY': '-L. -lpython3.7',
- 'BLDSHARED': 'gcc -pthread -shared -L. -L/usr/lib -Wl,-R/usr/lib '
+ 'BINLIBDEST': '/usr/pkg/lib/python3.8',
+ 'BLDLIBRARY': '-L. -lpython3.8',
+ 'BLDSHARED': 'gcc -pthread -shared -L. -Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib '
               '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
-              '-Wl,-R/usr/X11R7/lib -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
-              '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
+              '-Wl,-R/usr/X11R7/lib -Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib '
+              '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
+              '-Wl,-R/usr/X11R7/lib',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'armv7--netbsdelf-eabihf',
+ 'BUILD_GNU_TYPE': 'powerpc--netbsd',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -fPIC '
-           '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include -O2 -fPIC '
-           '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include -O2 -fPIC '
-           '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include',
+ 'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -I/usr/include '
+           '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include -O2 '
+           '-I/usr/include -I/usr/pkg/include',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-O2 -fPIC -D_FORTIFY_SOURCE=2 -I/usr/include '
-                     '-I/usr/pkg/include',
+ 'CONFIGURE_CFLAGS': '-O2 -I/usr/include -I/usr/pkg/include',
  'CONFIGURE_CFLAGS_NODIST': '-std=gnu99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
-                            '-Wno-cast-function-type '
                             '-Werror=implicit-function-declaration',
  'CONFIGURE_CPPFLAGS': '-I/usr/include -I/usr/pkg/include',
- 'CONFIGURE_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+ 'CONFIGURE_LDFLAGS': '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                       '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
                       '-Wl,-R/usr/X11R7/lib',
  'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/usr' '--with-system-ffi' "
-                "'--without-ensurepip' '--without-pymalloc' "
-                "'--prefix=/usr/pkg' '--build=armv7--netbsdelf-eabihf' "
-                "'--host=armv7--netbsdelf-eabihf' '--mandir=/usr/pkg/man' "
-                "'--enable-option-checking=yes' "
-                "'build_alias=armv7--netbsdelf-eabihf' "
-                "'host_alias=armv7--netbsdelf-eabihf' 'CC=gcc' 'CFLAGS=-O2 "
-                "-fPIC -D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include' "
-                "'LDFLAGS=-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib "
+ 'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/usr' '--with-system-expat' "
+                "'--with-system-ffi' '--without-ensurepip' "
+                "'--without-pymalloc' '--prefix=/usr/pkg' "
+                "'--build=powerpc--netbsd' '--host=powerpc--netbsd' "
+                "'--mandir=/usr/pkg/man' '--enable-option-checking=yes' "
+                "'build_alias=powerpc--netbsd' 'host_alias=powerpc--netbsd' "
+                "'CC=gcc' 'CFLAGS=-O2 -I/usr/include -I/usr/pkg/include' "
+                "'LDFLAGS=-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib "
                 "-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib' "
                 "'LIBS=' 'CPPFLAGS=-I/usr/include -I/usr/pkg/include' "
-                "'PKG_CONFIG=/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/.tools/bin/pkg-config' "
+                "'PKG_CONFIG=/usr/pkgsrc/lang/python38/work/.tools/bin/pkg-config' "
                 "'PKG_CONFIG_PATH=' "
-                "'PKG_CONFIG_LIBDIR=/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/.buildlink/lib/pkgconfig:/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/.buildlink/share/pkgconfig'",
+                "'PKG_CONFIG_LIBDIR=/usr/pkgsrc/lang/python38/work/.buildlink/lib/pkgconfig:/usr/pkgsrc/lang/python38/work/.buildlink/share/pkgconfig'",
  'CONFINCLUDEDIR': '/usr/pkg/include',
- 'CONFINCLUDEPY': '/usr/pkg/include/python3.7',
+ 'CONFINCLUDEPY': '/usr/pkg/include/python3.8',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.17/coverage.info',
- 'COVERAGE_REPORT': '/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.17/lcov-report',
+ 'COVERAGE_INFO': '/usr/pkgsrc/lang/python38/work/Python-3.8.19/coverage.info',
+ 'COVERAGE_REPORT': '/usr/pkgsrc/lang/python38/work/Python-3.8.19/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include -I/usr/include '
              '-I/usr/pkg/include',
  'CXX': 'c++ -pthread',
- 'DESTDIRS': '/usr/pkg /usr/pkg/lib /usr/pkg/lib/python3.7 '
-             '/usr/pkg/lib/python3.7/lib-dynload',
- 'DESTLIB': '/usr/pkg/lib/python3.7',
+ 'DESTDIRS': '/usr/pkg /usr/pkg/lib /usr/pkg/lib/python3.8 '
+             '/usr/pkg/lib/python3.8/lib-dynload',
+ 'DESTLIB': '/usr/pkg/lib/python3.8',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/pkg/lib/python3.7/lib-dynload',
+ 'DESTSHARED': '/usr/pkg/lib/python3.8/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -81,8 +79,8 @@ build_time_vars = {'ABIFLAGS': '',
  'DLINCLDIR': '.',
  'DLLLIBRARY': '',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
- 'DOUBLE_IS_BIG_ENDIAN_IEEE754': 0,
- 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
+ 'DOUBLE_IS_BIG_ENDIAN_IEEE754': 1,
+ 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 0,
  'DTRACE': '',
  'DTRACE_DEPS': '\\',
  'DTRACE_HEADERS': '',
@@ -96,6 +94,7 @@ build_time_vars = {'ABIFLAGS': '',
  'EXTRA_CFLAGS': '',
  'EXT_SUFFIX': '.so',
  'FILEMODE': 644,
+ 'FLOAT_WORDS_BIGENDIAN': 1,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
  'GETTIMEOFDAY_NO_TZ': 0,
@@ -136,6 +135,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
  'HAVE_COPYSIGN': 1,
+ 'HAVE_COPY_FILE_RANGE': 0,
  'HAVE_CRYPT_H': 0,
  'HAVE_CRYPT_R': 0,
  'HAVE_CTERMID': 1,
@@ -184,6 +184,8 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ERFC': 1,
  'HAVE_ERRNO_H': 1,
  'HAVE_EXECV': 1,
+ 'HAVE_EXPLICIT_BZERO': 0,
+ 'HAVE_EXPLICIT_MEMSET': 1,
  'HAVE_EXPM1': 1,
  'HAVE_FACCESSAT': 1,
  'HAVE_FCHDIR': 1,
@@ -194,7 +196,8 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_FCNTL_H': 1,
  'HAVE_FDATASYNC': 1,
  'HAVE_FDOPENDIR': 1,
- 'HAVE_FEXECVE': 1,
+ 'HAVE_FDWALK': 0,
+ 'HAVE_FEXECVE': 0,
  'HAVE_FINITE': 1,
  'HAVE_FLOCK': 1,
  'HAVE_FORK': 1,
@@ -220,7 +223,9 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GCC_UINT128_T': 0,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
- 'HAVE_GETENTROPY': 1,
+ 'HAVE_GETENTROPY': 0,
+ 'HAVE_GETGRGID_R': 1,
+ 'HAVE_GETGRNAM_R': 1,
  'HAVE_GETGROUPLIST': 1,
  'HAVE_GETGROUPS': 1,
  'HAVE_GETHOSTBYNAME': 0,
@@ -239,7 +244,9 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GETPID': 1,
  'HAVE_GETPRIORITY': 1,
  'HAVE_GETPWENT': 1,
- 'HAVE_GETRANDOM': 1,
+ 'HAVE_GETPWNAM_R': 1,
+ 'HAVE_GETPWUID_R': 1,
+ 'HAVE_GETRANDOM': 0,
  'HAVE_GETRANDOM_SYSCALL': 0,
  'HAVE_GETRESGID': 0,
  'HAVE_GETRESUID': 0,
@@ -284,7 +291,9 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LINUX_CAN_H': 0,
  'HAVE_LINUX_CAN_RAW_FD_FRAMES': 0,
  'HAVE_LINUX_CAN_RAW_H': 0,
+ 'HAVE_LINUX_MEMFD_H': 0,
  'HAVE_LINUX_NETLINK_H': 0,
+ 'HAVE_LINUX_QRTR_H': 0,
  'HAVE_LINUX_RANDOM_H': 0,
  'HAVE_LINUX_TIPC_H': 0,
  'HAVE_LINUX_VM_SOCKETS_H': 0,
@@ -294,8 +303,10 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LONG_DOUBLE': 1,
  'HAVE_LSTAT': 1,
  'HAVE_LUTIMES': 1,
+ 'HAVE_MADVISE': 1,
  'HAVE_MAKEDEV': 1,
  'HAVE_MBRTOWC': 1,
+ 'HAVE_MEMFD_CREATE': 0,
  'HAVE_MEMORY_H': 1,
  'HAVE_MEMRCHR': 1,
  'HAVE_MKDIRAT': 1,
@@ -306,7 +317,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_MKTIME': 1,
  'HAVE_MMAP': 1,
  'HAVE_MREMAP': 1,
- 'HAVE_NCURSES_H': 0,
+ 'HAVE_NCURSES_H': 1,
  'HAVE_NDIR_H': 0,
  'HAVE_NETCAN_CAN_H': 1,
  'HAVE_NETPACKET_PACKET_H': 0,
@@ -323,12 +334,14 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_POSIX_FADVISE': 1,
  'HAVE_POSIX_FALLOCATE': 1,
  'HAVE_POSIX_SPAWN': 1,
+ 'HAVE_POSIX_SPAWNP': 1,
  'HAVE_PREAD': 1,
  'HAVE_PREADV': 1,
  'HAVE_PREADV2': 0,
  'HAVE_PRLIMIT': 0,
  'HAVE_PROCESS_H': 0,
  'HAVE_PROTOTYPES': 1,
+ 'HAVE_PTHREAD_CONDATTR_SETCLOCK': 1,
  'HAVE_PTHREAD_DESTRUCTOR': 0,
  'HAVE_PTHREAD_GETCPUCLOCKID': 1,
  'HAVE_PTHREAD_H': 1,
@@ -354,6 +367,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_RL_PRE_INPUT_HOOK': 1,
  'HAVE_RL_RESIZE_TERMINAL': 1,
  'HAVE_ROUND': 1,
+ 'HAVE_RTPSPAWN': 0,
  'HAVE_SCHED_GET_PRIORITY_MAX': 1,
  'HAVE_SCHED_H': 1,
  'HAVE_SCHED_RR_GET_INTERVAL': 1,
@@ -383,8 +397,11 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SETUID': 1,
  'HAVE_SETVBUF': 1,
  'HAVE_SHADOW_H': 0,
+ 'HAVE_SHM_OPEN': 1,
+ 'HAVE_SHM_UNLINK': 1,
  'HAVE_SIGACTION': 1,
  'HAVE_SIGALTSTACK': 1,
+ 'HAVE_SIGFILLSET': 1,
  'HAVE_SIGINFO_T_SI_BAND': 1,
  'HAVE_SIGINTERRUPT': 1,
  'HAVE_SIGNAL_H': 1,
@@ -413,6 +430,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_STRING_H': 1,
  'HAVE_STRLCPY': 1,
  'HAVE_STROPTS_H': 0,
+ 'HAVE_STRSIGNAL': 1,
  'HAVE_STRUCT_PASSWD_PW_GECOS': 1,
  'HAVE_STRUCT_PASSWD_PW_PASSWD': 1,
  'HAVE_STRUCT_STAT_ST_BIRTHTIME': 1,
@@ -439,12 +457,14 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYS_KERN_CONTROL_H': 0,
  'HAVE_SYS_LOADAVG_H': 0,
  'HAVE_SYS_LOCK_H': 1,
+ 'HAVE_SYS_MEMFD_H': 0,
  'HAVE_SYS_MKDEV_H': 0,
+ 'HAVE_SYS_MMAN_H': 1,
  'HAVE_SYS_MODEM_H': 0,
  'HAVE_SYS_NDIR_H': 0,
  'HAVE_SYS_PARAM_H': 1,
  'HAVE_SYS_POLL_H': 1,
- 'HAVE_SYS_RANDOM_H': 1,
+ 'HAVE_SYS_RANDOM_H': 0,
  'HAVE_SYS_RESOURCE_H': 1,
  'HAVE_SYS_SELECT_H': 1,
  'HAVE_SYS_SENDFILE_H': 0,
@@ -506,59 +526,60 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'armv7--netbsdelf-eabihf',
+ 'HOST_GNU_TYPE': 'powerpc--netbsd',
  'INCLDIRSTOMAKE': '/usr/pkg/include /usr/pkg/include '
-                   '/usr/pkg/include/python3.7 /usr/pkg/include/python3.7',
+                   '/usr/pkg/include/python3.8 /usr/pkg/include/python3.8',
  'INCLUDEDIR': '/usr/pkg/include',
- 'INCLUDEPY': '/usr/pkg/include/python3.7',
- 'INSTALL': '/usr/bin/install -c -o root -g wheel',
- 'INSTALL_DATA': '/usr/bin/install -c -o root -g wheel -m 644',
- 'INSTALL_PROGRAM': '/usr/bin/install -c -s -o root -g wheel -m 755',
- 'INSTALL_SCRIPT': '/usr/bin/install -c -o root -g wheel -m 755',
- 'INSTALL_SHARED': '/usr/bin/install -c -o root -g wheel -m 555',
- 'INSTSONAME': 'libpython3.7.so.1.0',
+ 'INCLUDEPY': '/usr/pkg/include/python3.8',
+ 'INSTALL': '/usr/bin/install -c -o pbulk -g users',
+ 'INSTALL_DATA': '/usr/bin/install -c -o pbulk -g users -m 644',
+ 'INSTALL_PROGRAM': '/usr/bin/install -c -s -o pbulk -g users -m 755',
+ 'INSTALL_SCRIPT': '/usr/bin/install -c -o pbulk -g users -m 755',
+ 'INSTALL_SHARED': '/usr/bin/install -c -o pbulk -g users -m 755',
+ 'INSTSONAME': 'libpython3.8.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'c++ -pthread -shared',
- 'LDFLAGS': '-L. -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
-            '-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib -L/usr/lib -Wl,-R/usr/lib '
-            '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
-            '-Wl,-R/usr/X11R7/lib',
+ 'LDFLAGS': '-L. -Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+            '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
+            '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+            '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'LDFLAGS_NODIST': '',
- 'LDLAST': '',
- 'LDLIBRARY': 'libpython3.7.so',
+ 'LDLIBRARY': 'libpython3.8.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -pthread -shared -L. -L/usr/lib -Wl,-R/usr/lib '
+ 'LDSHARED': 'gcc -pthread -shared -L. -Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib '
              '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
-             '-Wl,-R/usr/X11R7/lib -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
-             '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
- 'LDVERSION': '3.7',
+             '-Wl,-R/usr/X11R7/lib -Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib '
+             '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
+             '-Wl,-R/usr/X11R7/lib',
+ 'LDVERSION': '3.8',
  'LIBC': '',
- 'LIBDEST': '/usr/pkg/lib/python3.7',
+ 'LIBDEST': '/usr/pkg/lib/python3.8',
  'LIBDIR': '/usr/pkg/lib',
- 'LIBFFI_INCLUDEDIR': '',
+ 'LIBFFI_INCLUDEDIR': '/usr/pkg/include',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/usr/pkg/lib/pkgconfig',
- 'LIBPL': '/usr/pkg/lib/python3.7/config-3.7',
- 'LIBRARY': 'libpython3.7.a',
+ 'LIBPL': '/usr/pkg/lib/python3.8/config-3.8',
+ 'LIBPYTHON': '',
+ 'LIBRARY': 'libpython3.8.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
- 'LIBS': '-lcrypt -lintl -lpthread  -lutil',
+ 'LIBS': '-lcrypt -lintl -lpthread  -lutil -lm',
  'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
  'LINKCC': 'gcc -pthread',
  'LINKFORSHARED': '-Wl,--export-dynamic',
  'LIPO_32BIT_FLAGS': '',
+ 'LIPO_INTEL64_FLAGS': '',
  'LLVM_PROF_ERR': 'no',
  'LLVM_PROF_FILE': '',
  'LLVM_PROF_MERGER': 'true',
  'LN': '/bin/ln',
  'LOCALMODLIBS': '',
- 'LOG1P_DROPS_ZERO_SIGN': 0,
  'MACHDEP': 'netbsd9',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/pkg/lib/python3.7',
+ 'MACHDESTLIB': '/usr/pkg/lib/python3.8',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
@@ -568,8 +589,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MKDIR_P': '/bin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
                    '_operator  _collections  _abc  itertools  atexit  _signal  '
-                   '_stat  time  _thread  _locale  _io  zipimport  '
-                   'faulthandler  _tracemalloc  _symtable  xxsubtype',
+                   '_stat  time  _thread  _locale  _io  faulthandler  '
+                   '_tracemalloc  _symtable  xxsubtype',
  'MODDISABLED_NAMES': '',
  'MODLIBS': '',
  'MODOBJS': 'Modules/posixmodule.o  Modules/errnomodule.o  '
@@ -581,10 +602,9 @@ build_time_vars = {'ABIFLAGS': '',
             'Modules/timemodule.o  Modules/_threadmodule.o  '
             'Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o '
             'Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o '
-            'Modules/textio.o Modules/stringio.o  Modules/zipimport.o  '
-            'Modules/faulthandler.o  Modules/_tracemalloc.o '
-            'Modules/hashtable.o  Modules/symtablemodule.o  '
-            'Modules/xxsubtype.o',
+            'Modules/textio.o Modules/stringio.o  Modules/faulthandler.o  '
+            'Modules/_tracemalloc.o Modules/hashtable.o  '
+            'Modules/symtablemodule.o  Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': '',
  'MULTIARCH_CPPFLAGS': '',
@@ -594,8 +614,7 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_INCLUDES': '-I/usr/include',
  'OPENSSL_LDFLAGS': '-L/usr/lib',
  'OPENSSL_LIBS': '-lssl -lcrypto',
- 'OPT': '-DNDEBUG -O2 -fPIC -D_FORTIFY_SOURCE=2 -I/usr/include '
-        '-I/usr/pkg/include',
+ 'OPT': '-DNDEBUG -O2 -I/usr/include -I/usr/pkg/include',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -605,14 +624,11 @@ build_time_vars = {'ABIFLAGS': '',
  'PACKAGE_VERSION': 0,
  'PARSER_HEADERS': '\\',
  'PARSER_OBJS': '\\ Parser/myreadline.o Parser/parsetok.o Parser/tokenizer.o',
- 'PGEN': 'Parser/pgen',
- 'PGENOBJS': '\\ \\',
- 'PGOBJS': '\\',
  'PGO_PROF_GEN_FLAG': '-fprofile-generate',
  'PGO_PROF_USE_FLAG': '-fprofile-use -fprofile-correction',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test.regrtest --pgo',
+ 'PROFILE_TASK': '-m test --pgo',
  'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -629,76 +645,72 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
-                             '-fPIC -D_FORTIFY_SOURCE=2 -I/usr/include '
-                             '-I/usr/pkg/include -O2 -fPIC -D_FORTIFY_SOURCE=2 '
-                             '-I/usr/include -I/usr/pkg/include -O2 -fPIC '
-                             '-D_FORTIFY_SOURCE=2 -I/usr/include '
-                             '-I/usr/pkg/include -std=gnu99 -Wextra '
-                             '-Wno-unused-result -Wno-unused-parameter '
+                             '-I/usr/include -I/usr/pkg/include -O2 '
+                             '-I/usr/include -I/usr/pkg/include -O2 '
+                             '-I/usr/include -I/usr/pkg/include -std=gnu99 '
+                             '-Wextra -Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
-                             '-Wno-cast-function-type '
-                             '-Werror=implicit-function-declaration -I. '
-                             '-I./Include -I/usr/include -I/usr/pkg/include '
-                             '-I/usr/include -I/usr/pkg/include -fPIC '
-                             '-DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -fPIC '
-              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include -O2 -fPIC '
-              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include -O2 -fPIC '
-              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include',
+                             '-Werror=implicit-function-declaration  '
+                             '-I./Include/internal -I. -I./Include '
+                             '-I/usr/include -I/usr/pkg/include -I/usr/include '
+                             '-I/usr/pkg/include -fPIC -DPy_BUILD_CORE_BUILTIN',
+ 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -I/usr/include '
+              '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include -O2 '
+              '-I/usr/include -I/usr/pkg/include',
  'PY_CFLAGS_NODIST': '-std=gnu99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
-                     '-Wno-cast-function-type '
-                     '-Werror=implicit-function-declaration',
+                     '-Werror=implicit-function-declaration  '
+                     '-I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -fPIC '
-                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include -O2 '
-                   '-fPIC -D_FORTIFY_SOURCE=2 -I/usr/include '
-                   '-I/usr/pkg/include -O2 -fPIC -D_FORTIFY_SOURCE=2 '
-                   '-I/usr/include -I/usr/pkg/include -std=gnu99 -Wextra '
-                   '-Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers -Wno-cast-function-type '
-                   '-Werror=implicit-function-declaration -I. -I./Include '
-                   '-I/usr/include -I/usr/pkg/include -I/usr/include '
-                   '-I/usr/pkg/include -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-L. -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+ 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
+                   '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
+                   '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
+                   '-std=gnu99 -Wextra -Wno-unused-result '
+                   '-Wno-unused-parameter -Wno-missing-field-initializers '
+                   '-Werror=implicit-function-declaration  '
+                   '-I./Include/internal -I. -I./Include -I/usr/include '
+                   '-I/usr/pkg/include -I/usr/include -I/usr/pkg/include -fPIC '
+                   '-DPy_BUILD_CORE',
+ 'PY_CORE_LDFLAGS': '-L. -Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                     '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
-                    '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+                    '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                     '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include '
                 '-I/usr/include -I/usr/pkg/include',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-L. -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+ 'PY_LDFLAGS': '-L. -Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
-               '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
-               '-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
+               '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+               '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'PY_LDFLAGS_NODIST': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -fPIC '
-                        '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
-                        '-O2 -fPIC -D_FORTIFY_SOURCE=2 -I/usr/include '
-                        '-I/usr/pkg/include -O2 -fPIC -D_FORTIFY_SOURCE=2 '
-                        '-I/usr/include -I/usr/pkg/include -std=gnu99 -Wextra '
+ 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
+                        '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
+                        '-I/usr/pkg/include -O2 -I/usr/include '
+                        '-I/usr/pkg/include -std=gnu99 -Wextra '
                         '-Wno-unused-result -Wno-unused-parameter '
                         '-Wno-missing-field-initializers '
-                        '-Wno-cast-function-type '
-                        '-Werror=implicit-function-declaration -I. -I./Include '
-                        '-I/usr/include -I/usr/pkg/include -I/usr/include '
-                        '-I/usr/pkg/include -fPIC',
+                        '-Werror=implicit-function-declaration  '
+                        '-I./Include/internal -I. -I./Include -I/usr/include '
+                        '-I/usr/pkg/include -I/usr/include -I/usr/pkg/include '
+                        '-fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
+ 'Py_TRACE_REFS': 0,
  'QUICKTESTOPTS': '-x test_subprocess test_io test_lib2to3 \\',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.17',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/pkgsrc/lang/python38/work/Python-3.8.19',
  'SCRIPTDIR': '/usr/pkg/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
- 'SHLIBS': '-lcrypt -lintl -lpthread  -lutil',
+ 'SHLIBS': '-lcrypt -lintl -lpthread  -lutil -lm',
  'SHLIB_SUFFIX': '.so',
+ 'SHM_NEEDS_LIBRT': 1,
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
  'SIZEOF_DOUBLE': 8,
@@ -719,7 +731,7 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-37',
+ 'SOABI': 'cpython-38',
  'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
@@ -729,15 +741,14 @@ build_time_vars = {'ABIFLAGS': '',
  'SUBDIRSTOO': 'Include Lib Misc',
  'SYSLIBS': '-lm',
  'SYS_SELECT_WITH_SYS_TIME': 1,
- 'TANH_PRESERVES_ZERO_SIGN': 1,
  'TCLTK_INCLUDES': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.17 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/pkgsrc/lang/python38/work/Python-3.8.19 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.17 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/pkgsrc/lang/python38/work/Python-3.8.19 '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -747,7 +758,7 @@ build_time_vars = {'ABIFLAGS': '',
  'UNIVERSALSDK': '',
  'UPDATE_FILE': 'python3 ./Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
- 'VERSION': '3.7',
+ 'VERSION': '3.8',
  'WINDOW_HAS_FLAGS': 0,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
@@ -759,8 +770,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.17',
- 'abs_srcdir': '/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.17',
+ 'abs_builddir': '/usr/pkgsrc/lang/python38/work/Python-3.8.19',
+ 'abs_srcdir': '/usr/pkgsrc/lang/python38/work/Python-3.8.19',
  'datarootdir': '/usr/pkg/share',
  'exec_prefix': '/usr/pkg',
  'prefix': '/usr/pkg',
